library(snowfall)


pbsnodefile = Sys.getenv("PBS_NODEFILE")
machines <- scan(pbsnodefile, what="")
machines
nmach = length(machines)
nmach


library(rlecuyer)
library(isotone)
library(KernSmooth) 


#Please change the following constant before run the program
num_iterations = 1000 ###change to 1000
num_cpus = nmach      ###change to the number of CPUs you can get


sfInit(parallel=TRUE, cpus=num_cpus, type="SOCK", socketHosts=machines)


sfLibrary(isotone)
sfLibrary(KernSmooth)
sfLibrary(snowfall)
sfLibrary(rlecuyer)





### Read in the original data

data <- read.csv('data.csv') 
data <- data[order(data$Time),] # full dataset used for the marginal estimation

attach(data) # for marginal probabilities

Time = data$Time
state = data$state
nid = data$nid
n.clus.size = data$n.clus.size



### choose the covariate column


col.x <- 4 # BMI

Z <- data[,col.x]
size <- n.clus.size
ID <- nid


### Value of Covariate BMI

Z_vec <- quantile(Z, c(0.1,0.25,0.5,0.75,0.9))


# random seed pool
#set.seed(50)


### grid size and bin size. For data application only use the data points at each year of age
 bin <- 0.25; m <- 100



### Obtain the necessary functions
sfSource("PLE.Z.R")
sfSource("L1test.Z.R")
sfExportAll()
sfExport("Time", "state")


#install.packages('rlecuyer')
## Set up random number generator on network
## sfClusterSetupRNG( ) ## default

sfClusterSetupRNG( )

res.list = sfLapply(1:num_iterations, sim.fun)
sfStop()
print(res.list)




res.df = do.call(rbind, res.list)

res.df.delta0 = res.df[,1:7]
res.df.delta = res.df[,8:14]

# code for output files
delta0_file <- paste("sim",colnames(data)[col.x],num_iterations, "delta0", "dat",sep=".")
delta_file <- paste("sim",colnames(data)[col.x],num_iterations, "delta1", "dat",sep=".")
write.table(res.df.delta0, file=delta0_file, sep="\t", quote=F, row.name=F)
write.table(res.df.delta, file=delta_file, sep="\t", quote=F, row.name=F)










